You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ak...@apache.org on 2008/03/29 21:36:55 UTC

svn commit: r642601 - in /directory/sandbox/akarasulu/bigbang/apacheds: core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java schema-bootstrap/src/main/schema/apache.schema

Author: akarasulu
Date: Sat Mar 29 13:36:54 2008
New Revision: 642601

URL: http://svn.apache.org/viewvc?rev=642601&view=rev
Log:
adding apacheSublevel attribute type for use with sublevel index

Modified:
    directory/sandbox/akarasulu/bigbang/apacheds/core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java
    directory/sandbox/akarasulu/bigbang/apacheds/schema-bootstrap/src/main/schema/apache.schema

Modified: directory/sandbox/akarasulu/bigbang/apacheds/core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java
URL: http://svn.apache.org/viewvc/directory/sandbox/akarasulu/bigbang/apacheds/core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java?rev=642601&r1=642600&r2=642601&view=diff
==============================================================================
--- directory/sandbox/akarasulu/bigbang/apacheds/schema-bootstrap/src/main/schema/apache.schema (original)
+++ directory/sandbox/akarasulu/bigbang/apacheds/schema-bootstrap/src/main/schema/apache.schema Sat Mar 29 13:36:54 2008
@@ -2,17 +2,18 @@
 #                                Apache Schema
 # =============================================================================
 #
-#              +-----------------------------+-----------------+
-#              |  Apache AttributeType OID   |      name       |
-#              +-----------------------------+-----------------+
-#              | 1.3.6.1.4.1.18060.0.4.1.2.1 | apacheNdn       |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.2 | apacheUpdn      |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.3 | apacheExistance |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.4 | apacheHierarchy |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.5 | apacheOneAlias  |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.6 | apacheSubAlias  |
-#              | 1.3.6.1.4.1.18060.0.4.1.2.7 | apacheAlias     |
-#              +-----------------------------+-----------------+
+#              +------------------------------+-----------------+
+#              |  Apache AttributeType OID    |      name       |
+#              +------------------------------+-----------------+
+#              | 1.3.6.1.4.1.18060.0.4.1.2.1  | apacheNdn       |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.2  | apacheUpdn      |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.3  | apacheExistance |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.4  | apacheHierarchy |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.5  | apacheOneAlias  |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.6  | apacheSubAlias  |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.7  | apacheAlias     |
+#              | 1.3.6.1.4.1.18060.0.4.1.2.43 | apacheSublevel  |
+#              +------------------------------+-----------------+
 # =============================================================================
 
 
@@ -70,6 +71,13 @@
     NO-USER-MODIFICATION
     USAGE dSAOperation )
 
+attributetype ( 1.3.6.1.4.1.18060.0.4.1.2.43 NAME 'apacheSublevel'
+    DESC 'Index attribute used to track descendants'
+    EQUALITY integerMatch
+    SYNTAX 1.3.6.1.4.1.1466.115.121.1.27
+    NO-USER-MODIFICATION
+    USAGE dSAOperation )
+
 attributetype ( 1.3.6.1.4.1.18060.0.4.1.2.9 NAME 'apacheSamType'
     DESC 'Single-use Authentication Mechanism type/vendor code'
     EQUALITY integerMatch
@@ -463,4 +471,5 @@
 # =================================================
 # END SSL/TLS Key Management for LDAPS and StartTLS 
 # =================================================
-    
\ No newline at end of file
+
+# LAST ATTRIBUTE_TYPE WAS = 1.3.6.1.4.1.18060.0.4.1.2.43 START USING 1.3.6.1.4.1.18060.0.4.1.2.44
\ No newline at end of file
--- directory/sandbox/akarasulu/bigbang/apacheds/core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java (original)
+++ directory/sandbox/akarasulu/bigbang/apacheds/core-constants/src/main/java/org/apache/directory/server/core/partition/Oid.java Sat Mar 29 13:36:54 2008
@@ -42,8 +42,8 @@
     public static final String SUBALIAS = "1.3.6.1.4.1.18060.0.4.1.2.6";
     /** Private OID (1.3.6.1.4.1.18060.0.4.1.2.7) for _alias index */
     public static final String ALIAS = "1.3.6.1.4.1.18060.0.4.1.2.7";
-    /** Private OID (1.3.6.1.4.1.18060.0.4.1.2.8) for _subLevel index*/
-    public static final String SUBLEVEL = "1.3.6.1.4.1.18060.0.4.1.2.8";
+    /** Private OID (1.3.6.1.4.1.18060.0.4.1.2.43) for _subLevel index*/
+    public static final String SUBLEVEL = "1.3.6.1.4.1.18060.0.4.1.2.43";
     
     private Oid()
     {

Modified: directory/sandbox/akarasulu/bigbang/apacheds/schema-bootstrap/src/main/schema/apache.schema
URL: http://svn.apache.org/viewvc/directory/sandbox/akarasulu/bigbang/apacheds/schema-bootstrap/src/main/schema/apache.schema?rev=642601&r1=642600&r2=642601&view=diff
==============================================================================